ams.core.service.RBaseService
=============================

.. currentmodule:: ams.core.service

.. autoclass:: RBaseService

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~RBaseService.assign_memory
       
       
          ~RBaseService.evaluate
       
       
          ~RBaseService.get_names
       
       
          ~RBaseService.parse
       
       
          ~RBaseService.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~RBaseService.class_name
      ~RBaseService.n
      ~RBaseService.shape
      ~RBaseService.size
      ~RBaseService.v
   
   